%define realname qwt
%define major    6

Name:           libqwt
Version:        6.1.6
Release:        %mkrel 1
Summary:        2D plotting widget extension to the Qt GUI
License:        Qwt License 1.0
Group:          System/Libraries
Url:            https://qwt.sourceforge.io/
Source:         http://downloads.sourceforge.net/%{realname}/%{realname}-%{version}.tar.xz
## upstream patches

## upstreamable patches
# fix pkgconfig support
Patch50:        qwt-6.1.1-pkgconfig.patch
# use QT_INSTALL_ paths instead of custom prefix
Patch51:        qwt-6.1.5-qt_install_paths.patch
# parallel-installable qt5 version
Patch52:        qwt-qt5.patch
#
Patch53:        qwt-6.1.3-no_rpath.patch

### Qt4 BuildRequires
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtDesigner)
BuildRequires:  pkgconfig(QtSvg)

### Qt5 BuildRequires
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
Qwt is an extension to the Qt GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientifical purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

#------------------------------------------------------------------------------
### Qt4 ###

%define libname %mklibname %realname %{major}

%package -n     %{libname}
Summary:        2D plotting widget extension to the Qt4 GUI
Group:          System/Libraries

%description -n %{libname}
Qwt is an extension to the Qt4 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientifical purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname}
%{_qt4_libdir}/libqwt.so.%{major}*
%{_qt4_libdir}/libqwtmathml.so.%{major}*

#------------------------------------------------------------------------------

%define libnamedev %mklibname qwt -d

%package -n     %{libnamedev}
Summary:        Development tools for programs which uses Qt4 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname} = %{version}
Provides:       libqwt-devel = %{version}-%{release}
Provides:       libqwtmathml-devel = %{version}-%{release}
Conflicts:      %{_lib}qwt5-devel

%description -n %{libnamedev}
The %{libnamedev} package contains the header files and static libraries
necessary for developing programs using the Qt4 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt package.

%files -n %{libnamedev}
%docdir %{_qt4_docdir}/html/
%{_qt4_docdir}/html/qwt/
%{_qt4_docdir}/html/man/
%{_qt4_includedir}/qwt/
%{_qt4_libdir}/libqwt.so
%{_qt4_libdir}/libqwtmathml.so
%{_qt4_libdir}/pkgconfig/qwt.pc
%{_qt4_libdir}/pkgconfig/qwtmathml.pc
%{_qt4_datadir}/mkspecs/*

### End Qt4 ###

#------------------------------------------------------------------------------
#------------------------------------------------------------------------------

### Qt5 ###

%define libname_qt5 %mklibname %realname-qt5_ %{major}

%package -n     %{libname_qt5}
Summary:        2D plotting widget extension to the Qt5 GUI
Group:          System/Libraries

%description -n %{libname_qt5}
Qwt is an extension to the Qt5 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientifical purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname_qt5}
%{_qt5_libdir}/libqwt-qt5.so.%{major}*
%{_qt5_libdir}/libqwtmathml-qt5.so.%{major}*
%{_qt5_plugindir}/designer/libqwt_designer_plugin.so

#------------------------------------------------------------------------------

%define libnamedev_qt5 %mklibname qwt-qt5 -d

%package -n     %{libnamedev_qt5}
Summary:        Development tools for programs which uses Qt5 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname_qt5} = %{version}
Provides:       libqwt-qt5-devel = %{version}-%{release}
Provides:       libqwtmathml-qt5-devel = %{version}-%{release}

%description -n %{libnamedev_qt5}
The %{libnamedev_qt5} package contains the header files and static libraries
necessary for developing programs using the Qt5 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt-qt5 package.

%files -n %{libnamedev_qt5}
%doc COPYING
%doc examples
%docdir %{_qt5_docdir}/html/
%{_qt5_docdir}/html/qwt/
%{_qt5_includedir}/qwt/
%{_qt5_libdir}/libqwt-qt5.so
%{_qt5_libdir}/libqwtmathml-qt5.so
%{_qt5_libdir}/pkgconfig/Qt5Qwt6.pc
%{_qt5_libdir}/pkgconfig/qwtmathml-qt5.pc
%{_qt5_archdatadir}/mkspecs/*
%{_mandir}/man3/*

### End Qt5 ###
#------------------------------------------------------------------------------

%prep
%setup -q -n %{realname}-%{version}
%apply_patches

%build
### Qt5 Build ###
mkdir qt5 && pushd qt5
%qmake_qt5 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

### Qt4 Build ###
mkdir qt4 && pushd qt4
%qmake_qt4 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

%install
### Qt5 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt5

mv %{buildroot}%{_qt5_docdir}/html/html %{buildroot}%{_qt5_docdir}/html/qwt
mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_qt5_docdir}/html/man/man3 %{buildroot}%{_mandir}/

### Qt4 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt4

mv %{buildroot}%{_qt4_docdir}/html/html %{buildroot}%{_qt4_docdir}/html/qwt


%changelog
* Sun Mar 21 2021 pp 6.1.6-1pclos2021
- update

* Sun Sep 13 2020 tex - 6.1.5-2pclos2020
- rebuild against updates

* Tue Jul 14 2020 daviddavid <daviddavid> 6.1.5-1pclos2020
- new version: 6.1.5 (compatibility to Qt 5.15)
